@@ -69,10 +69,10 @@ Attribute       Description
 
 :Parameters:
 
-    year : int
+    year: `int`
         The year.
 
-    month, day, hour, minute, second, microsecond : ints, optional
+    month, day, hour, minute, second, microsecond: `int`, optional
         The month of the year, the day of the month and time of the
         day. *month* and *day* default to 1 and *hour*; *minute*,
         *second* and *microsecond* default to 0.
@@ -260,7 +260,7 @@ d.hour, d.minute, d.second)``.
 
 :Returns:
 
-    out : tuple
+    out: `tuple`
         The first six date-time attributes.
 
 :Examples:
@@ -283,7 +283,7 @@ Return a deep copy.
 
 :Returns:	
 
-    out :
+    out:
         The deep copy.
 
 :Examples:
@@ -326,7 +326,7 @@ d.minute, d.second, d.dayofwk, d.dayofyr, -1)``.
 
 :Returns:
 
-    out : tuple
+    out: `tuple`
         The date-time attributes.
 
 :Examples:
@@ -383,7 +383,7 @@ minute, second and microsecond.
 
 :Parameters:
 
-    args, kwargs :
+    args, kwargs:
         If the first positional argument is a string, then it must be
         an ISO 8601-like date-time string from which a `cf.Datetime`
         object is initialized. Otherwise, the positional and keyword
@@ -392,7 +392,7 @@ minute, second and microsecond.
 
 :Returns:
 
-    out : cf.Datetime
+    out: `cf.Datetime`
         The new date-time object.
 
 :Examples:
@@ -417,6 +417,8 @@ minute, second and microsecond.
         arg0 = args[0]
         if isinstance(arg0, basestring):
             return st2Datetime(arg0)
+        elif isinstance(arg0, datetime):
+            return Datetime(*arg0.timetuple()[:6])
         else:
             return Datetime(*args)
 #--- End: def
@@ -428,19 +430,19 @@ The returned array is always independent.
 
 :Parameters:
 
-    array : numpy array-like
+    array: numpy array-like
 
-    units_in : cf.Units
+    units_in: `cf.Units`
 
-    dummy0 : *optional*
+    dummy0: optional
         Ignored.
 
-    dummy1 : *optional*
+    dummy1: optional
         Ignored.
 
 :Returns: 
 
-    out : numpy array
+    out: `numpy.ndarray`
         An array of `cf.Datetime` or `datetime.datetime` objects with
         the same shape as *array*.
 
@@ -460,11 +462,11 @@ Parse an ISO 8601 date-time string into a datetime.datetime object.
 
 :Parameters:
 
-    date_string : str
+    date_string: `str`
 
 :Returns:
 
-    out : datetime.datetime
+    out: `datetime.datetime`
 
 '''
     if date_string.count('-') != 2:
@@ -486,11 +488,11 @@ Parse an ISO 8601 date-time string into a `cf.Datetime` object.
 
 :Parameters:
 
-    date_string : str
+    date_string: `str`
 
 :Returns:
 
-    out : cf.Datetime
+    out: `cf.Datetime`
 
 '''
     if date_string.count('-') != 2:
@@ -512,19 +514,19 @@ The returned array is always independent.
 
 :Parameters:
 
-    array : numpy array-like
+    array: numpy array-like
 
-    units_in : cf.Units
+    units_in: `cf.Units`
 
-    dummy0 :
+    dummy0:
         Ignored.
 
-    dummy1 :
+    dummy1:
         Ignored.
 
 :Returns: 
 
-    out : numpy array
+    out: `numpy.ndarray`
         An array of `cf.Datetime` or `datetime.datetime` objects with
         the same shape as *array*.
 
@@ -545,19 +547,19 @@ The returned array is always independent.
 
 :Parameters:
 
-    array : numpy array-like of date-time objects
+    array: numpy array-like of date-time objects
 
-    dummy0 :
+    dummy0:
         Ignored.
 
-    units_out : cf.Units
+    units_out: `cf.Units`
 
-    dummy1 :
+    dummy1:
         Ignored.
 
 :Returns: 
 
-    out : numpy array
+    out: `numpy.ndarray`
         An array of numbers with the same shape as *array*.
 
 '''
