@@ -2725,6 +2725,7 @@ False
         return _direction
     #--- End: def
 
+#ppp
     # DimensionCoordinate method
     def get_bounds(self, create=False, insert=False, bound=None,
                    cellsize=None, flt=0.5, copy=True):
@@ -2752,8 +2753,6 @@ create bounds based on the coordinate array values.
         bounds. Ignored if *create* is False.
 
     cellsize: optional
-        .. versionadded:: 1.2.2
-
         Define the exact size of each cell that is created. Created
         cells are allowed to overlap do not have to be contigious.
         Ignored if *create* is False. The *cellsize* parameter may be
@@ -2850,15 +2849,13 @@ create bounds based on the coordinate array values.
                  1st January 1984.
 
         {+data-like-scalar}
- 
-    flt: `float`, optional
-        .. versionadded:: 1.2.2
 
+    flt: `float`, optional
         When creating cells with sizes specified by the *cellsize*
         parameter, define the fraction of the each cell which is less
-        its coordinate value. By default *flt* is 0.5, so that each
-        cell's coordinate is at its centre. Ignored if *cellsize* is
-        not set.
+        its coordinate value. By default *flt* is 05, so that each
+        cell has its coordinate at it's centre. Ignored if *cellsize*
+        is not set. 
 
           *Example:*
              For coordinates ``1, 2, 10``, setting ``cellsize=1,
@@ -2890,12 +2887,9 @@ create bounds based on the coordinate array values.
 
 >>> c.get_bounds()
 >>> c.get_bounds(create=True)
+>>> c.get_bounds(create=True, bound=60)
 >>> c.get_bounds(create=True, insert=True)
->>> c.get_bounds(copy=False)
->>> c.get_bounds(create=True, insert=True, cellsize=cf.M())
->>> c.get_bounds(create=True, insert=True, cellsize=1)
->>> c.get_bounds(create=True, insert=True, cellsize=cf.Data(1, 'day'))
->>> c.get_bounds(create=True, cellsize=10, flt=0.25)
+>>> c.get_bounds(create=True, bound=-9000.0, insert=True, copy=False)
 
         '''
         if self._hasbounds:
