@@ -69,7 +69,7 @@ longer required.
 
 :Returns:
 
-    out : float
+    out: `float`
         The amount of available physical memory in bytes.
 
 :Examples:
@@ -112,7 +112,7 @@ The amount of available physical memory.
 
 :Returns:
 
-    out : float
+    out: float
         The amount of available physical memory in bytes.
 
 :Examples:
@@ -143,7 +143,7 @@ process has completed.
 
 :Returns:
 
-    out : float
+    out: `float`
         The amount of free memory in bytes.
 
 :Examples:
@@ -172,11 +172,11 @@ def SET_FREE_MEMORY(*arg):
 
 :Parameters:
 
-    arg : None, optional
+    arg: `None`, optional
 
 :Returns:
 
-    None
+    `None`
 
 :Examples:
 
@@ -197,7 +197,7 @@ The amount of memory which is kept free as a temporary work space.
 
 :Returns:
 
-    out : float
+    out: float
         The amount of memory in bytes.
 
 .. seealso:: `cf.CHUNKSIZE`, `cf.MINNCFM`
@@ -224,13 +224,13 @@ be kept free as a temporary work space is also updated.
 
 :Parameters:
 
-    size : int, optional
+    size: int, optional
         The new chunk size in bytes. The default is to not change the
         current value.
 
 :Returns:
 
-    out : float
+    out: float
         The value prior to the change, or the current value if no new
         value was specified.
 
@@ -274,13 +274,13 @@ A chunk of memory is the amount of memory set by `cf.CHUNKSIZE`.
  
 :Parameters:
 
-    arg : int, optional
+    arg: int, optional
         The number of chunks to be kept free as a temporary work
         space. The default is to not change the current value.
 
 :Returns:
 
-    out : int
+    out: int
         The value prior to the change, or the current value if no new
         value was specified.
 
@@ -317,7 +317,7 @@ not exist.
 
 :Parameters:
 
-    arg : str, optional
+    arg: str, optional
         The new directory for temporary files. Tilde expansion (an
         initial component of ``~`` or ``~user`` is replaced by that
         *user*'s home directory) and environment variable expansion
@@ -329,7 +329,7 @@ not exist.
 
 :Returns:
 
-    out : str
+    out: str
         The directory prior to the change, or the current directory if
         no new value was specified.
 
@@ -375,13 +375,13 @@ needed by a variable to access its data array.
 
 :Parameters:
 
-    arg : float, optional
+    arg: float, optional
         The new fraction (between 0.0 and 1.0). The default is to not
         change the current behaviour.
 
 :Returns:
 
-    out : float
+    out: float
         The value prior to the change, or the current value if no new
         value was specified.
 
@@ -426,13 +426,13 @@ If it is logging is performed after every call to ESMPy.
 
 :Parameters:
 
-    arg : bool, optional
+    arg: bool, optional
         The new value (either True to enable logging or False to disable it).
         The default is to not change the current behaviour.
 
 :Returns:
 
-    out : bool
+    out: bool
         The value prior to the change, or the current value if no new
         value was specified.
 
@@ -465,10 +465,10 @@ Otherwise ``cf.dump(x)`` is equivalent to ``print x``.
 
 :Parameters:
 
-    x :
+    x:
         The object to print.
 
-    kwargs : *optional*
+    kwargs: *optional*
         As for the input variable's `!dump` method, if it has one.
 
 :Returns:
@@ -516,7 +516,7 @@ fraction is retrieved and set with the `OF_FRACTION` function.
 
 :Returns:
 
-    out : bool
+    out: bool
         Whether or not the number of open files exceeds the threshold.
 
 .. seealso:: `cf.close_files`, `cf.close_one_file`, `cf.open_files`
@@ -555,7 +555,7 @@ fraction is retrieved and set with the `OF_FRACTION` function.
 
 :Returns:
 
-    out : bool
+    out: bool
         Whether or not the number of open files exceeds the threshold.
 
 .. seealso:: `cf.close_files`, `cf.close_one_file`, `cf.open_files`
@@ -591,7 +591,7 @@ If there are no appropriate open files then no action is taken.
 
 :Parameters:
 
-    file_format : str, optional
+    file_format: str, optional
         Only close files of the given format. Recognised formats are
         ``'netCDF'`` and ``'PP'``. By default files of any format are
         closed.
@@ -637,7 +637,7 @@ If there are no appropriate open files then no action is taken.
 
 :Parameters:
 
-    file_format : str, optional
+    file_format: str, optional
         Only close a file of the given format. Recognised formats are
         ``'netCDF'`` and ``'PP'``. By default a file of any format is
         closed.
@@ -692,13 +692,13 @@ restricted to files of a particular format.
 
 :Parameters:
 
-    file_format : str, optional
+    file_format: str, optional
         Only return files of the given format. Recognised formats are
         ``'netCDF'`` and ``'PP'``. By default all files are returned.
 
 :Returns:
 
-    out : dict
+    out: dict
         If *file_format* is set then return a dictionary of file names
         of the specified format and their open file objects. If
         *file_format* is not set then return a dictionary for which
@@ -742,17 +742,17 @@ unchanged to the variable's *name* method.
 
 :Parameters:
 
-    name : str
+    name: str
 
-    x :
+    x:
         The input variable.
 
-    args, kwargs :
+    args, kwargs:
 
 
 :Returns:
 
-    out : 
+    out: 
         A new variable with size 1 axes inserted into the data array.
 
 :Examples:
@@ -776,20 +776,20 @@ between ``a`` and ``b``.
 
 :Parameters:
 
-    a, b : array_like
+    a, b: array_like
         Input arrays to compare.
 
-    atol : float, optional
+    atol: float, optional
         The absolute tolerance for all numerical comparisons, By
         default the value returned by the `ATOL` function is used.
 
-    rtol : float, optional
+    rtol: float, optional
         The relative tolerance for all numerical comparisons, By
         default the value returned by the `RTOL` function is used.
 
 :Returns:
 
-    out : bool
+    out: bool
         Returns True if the arrays are equal, otherwise False.
 
 :Examples:
@@ -832,13 +832,13 @@ def parse_indices(data, indices, cyclic=False):
 
 :Parameters:
 
-    data : array-like
+    data: array-like
 
-    indices : tuple
+    indices: tuple
 
 :Returns:
 
-    out : list [, dict]
+    out: list [, dict]
 
 :Examples:
 
@@ -1040,9 +1040,9 @@ def get_subspace(array, indices):
 
 :Parameters:
 
-    array : numpy array
+    array: numpy array
 
-    indices : list
+    indices: list
 
 Subset the input numpy array with the given indices. Indexing is similar to
 that of a numpy array. The differences to numpy array indexing are:
@@ -1159,13 +1159,13 @@ equality.
 
 :Parameters:
 
-    arg : int, optional
+    arg: int, optional
         The new value of absolute tolerance. The default is to not
         change the current value.
 
 :Returns:
 
-    out : float
+    out: float
         The value prior to the change, or the current value if no
         new value was specified.
 
@@ -1198,13 +1198,13 @@ tolerant equality.
 
 :Parameters:
 
-    arg : int, optional
+    arg: int, optional
         The new value of relative tolerance. The default is to not
         change the current value.
 
 :Returns:
 
-    out : float
+    out: float
         The value prior to the change, or the current value if no
         new value was specified.
 
@@ -1246,25 +1246,25 @@ y)`` is equivalent to ``y.equals(x)``.
     x, y :
         The objects to compare for equality.
 
-    atol : float, optional
+    atol: float, optional
         The absolute tolerance for all numerical comparisons, By
         default the value returned by the `ATOL` function is used.
 
-    rtol : float, optional
+    rtol: float, optional
         The relative tolerance for all numerical comparisons, By
         default the value returned by the `RTOL` function is used.
 
-    ignore_fill_value : bool, optional
+    ignore_fill_value: bool, optional
         If True then `cf.Data` arrays with different fill values are
         considered equal. By default they are considered unequal.
 
-    traceback : bool, optional
+    traceback: bool, optional
         If True then print a traceback highlighting where the two
         objects differ.
 
 :Returns: 
 
-    out : bool
+    out: bool
         Whether or not the two objects are equal.
 
 :Examples:
@@ -1371,24 +1371,24 @@ used, and in this case ``equivalent(x, y)`` is the same as
 
 :Parameters:
 
-    x, y :
+    x, y:
         The objects to compare for equivalence.
 
-    atol : float, optional
+    atol: float, optional
         The absolute tolerance for all numerical comparisons, By
         default the value returned by the `ATOL` function is used.
 
-    rtol : float, optional
+    rtol: float, optional
         The relative tolerance for all numerical comparisons, By
         default the value returned by the `RTOL` function is used.
 
-    traceback : bool, optional
+    traceback: bool, optional
         If True then print a traceback highlighting where the two
         objects differ.
 
 :Returns: 
 
-    out : bool
+    out: bool
         Whether or not the two objects are equivalent.
 
 :Examples:
@@ -1439,14 +1439,14 @@ Return an iterator over an arbitrarily nested sequence.
 
 :Parameters:
 
-    x : scalar or arbitrarily nested sequence
+    x: scalar or arbitrarily nested sequence
         The arbitrarily nested sequence to be flattened. Note that a
         If *x* is a string or a scalar then this is equivalent to
         passing a single element sequence containing *x*.
 
 :Returns:
 
-    out : generator
+    out: generator
         An iterator over flattened sequence.
 
 :Examples:
@@ -1527,14 +1527,14 @@ The pickling is equivalent to::
 
 :Parameters:
 
-    x : 
+    x: 
         The object to be pickled.
 
-    filename : str
+    filename: str
         The name of the file in which to write the pickled
         representation of *x*.
 
-    overwrite : bool, optional
+    overwrite: bool, optional
         If True a pre-existing output file is over written. By default
         an exception is raised if the output file pre-exists.
 
@@ -1592,17 +1592,17 @@ The unpickling is equivalent to::
 
 :Parameters:
 
-    filename : str
+    filename: str
         The name of the file containing the pickled object.
 
 :Returns:
 
-    out : 
+    out: 
         The reconstituted object.
 
 :Raises:
 
-    UnpicklingError :
+    UnpicklingError:
         If the file can not be unpickled. In particular, this might be
         raised when attempting to unpickle fields which were pickled
         with a different, incompatible version of cf.
@@ -1658,12 +1658,12 @@ If a string containing URL is provided then it is returned unchanged.
 
 :Parameters:
 
-    filename : str
+    filename: str
         The name of the file.
 
 :Returns:
 
-    out : str
+    out: str
         The normalized absolutized version of *filename*.
  
 .. seealso:: `cf.dirname`, `cf.pathjoin`, `cf.relpath`
@@ -1700,16 +1700,16 @@ If a string containing URL is provided then it is returned unchanged.
 
 :Parameters:
 
-    filename : str
+    filename: str
         The name of the file.
 
-    start : str, optional
+    start: str, optional
         The start point for the relative path. By default the current
         directoty is used.
 
 :Returns:
 
-    out : str
+    out: str
         The relative path.
 
 .. seealso:: `cf.abspath`, `cf.dirname`, `cf.pathjoin`
@@ -1744,12 +1744,12 @@ including, the last slash (/) is returned.
 
 :Parameters:
 
-    filename : str
+    filename: str
         The name of the file.
 
 :Returns:
 
-    out : str
+    out: str
         The directory name.
 
 .. seealso:: `cf.abspath`, `cf.pathjoin`, `cf.relpath`
@@ -1780,15 +1780,15 @@ If either of the paths is a URL then a URL will be returned
 
 :Parameters:
 
-    path1 : str
+    path1: str
         The first component of the path.
 
-    path2 : str
+    path2: str
         The second component of the path.
 
 :Returns:
 
-    out : str
+    out: str
         The joined paths.
 
 .. seealso:: `cf.abspath`, `cf.dirname`, `cf.relpath`
@@ -1827,12 +1827,12 @@ Python, numpy and cf.
 
 :Parameters:
 
-    array : numpy.ndarray
+    array: numpy.ndarray
         The numpy array to be hashed. May be a masked array.
 
 :Returns:
 
-    out : int
+    out: int
         The hash value
 
 :Examples:
@@ -1900,7 +1900,7 @@ Inspect the attributes of an object.
 
 :Returns: 
 
-    out : str
+    out: str
 
 :Examples:
 
@@ -1939,13 +1939,13 @@ For example, ``a[...] = broadcast_array(a, b.shape)`` is equivalent to
     
 :Parameters:
   
-    a : numpy array-like
+    a: numpy array-like
     
-    shape : tuple
+    shape: tuple
     
 :Returns:
 
-    out : numpy array
+    out: numpy array
     
 :Examples:
 
@@ -2019,20 +2019,20 @@ between ``a`` and ``b``.
 
 :Parameters:
 
-    x, y : array_like
+    x, y: array_like
         Input arrays to compare.
 
-    atol : float, optional
+    atol: float, optional
         The absolute tolerance for all numerical comparisons, By
         default the value returned by the `ATOL` function is used.
 
-    rtol : float, optional
+    rtol: float, optional
         The relative tolerance for all numerical comparisons, By
         default the value returned by the `RTOL` function is used.
 
 :Returns:
 
-    out : bool
+    out: bool
         Returns True if the arrays are equal, otherwise False.
 
 :Examples:
@@ -2072,7 +2072,7 @@ cf.Data.
 
 :Parameters:
 
-    axes : *optional*
+    axes: *optional*
         In the case of a Field this is a query for the m axes that
         define the sections of the Field as accepted by the Field
         object's axes method.  The keyword arguments are also passed
@@ -2083,29 +2083,29 @@ cf.Data.
         indices of the m axes that define the sections of the Data
         object. If axes is None (the default) all axes are selected.
     
-    data : bool, optional
+    data: bool, optional
         If True this indicates that a data object has been passed, if
         False it indicates that a field object has been passed. By
         default it is False.
 
-    stop : int, optional
+    stop: int, optional
         Stop after taking this number of sections and return. If stop
         is None all sections are taken.
     
-    chunks : bool, optional
+    chunks: bool, optional
         If True return sections that are of the maximum possible size
         that will fit in one chunk of memory instead of sectioning
         into slices of size 1 along the dimensions that are being
         sectioned.
     
-    min_step : int, optional
+    min_step: int, optional
         The minimum step size when making chunks. By default this is
         1. Can be set higher to avoid size 1 dimensions, which are
         problematic for bilinear regridding.
 
 :Returns:
 
-    out : list or dict
+    out: list or dict
         The list of m dimensional sections of the Field or the
         dictionary of m dimensional sections of the Data object.
 
