@@ -551,6 +551,8 @@ cell_methods)
     f.file  = filename
     f.Units = f_Units
 
+    f._global_attributes = tuple(global_attributes)
+
     # Map netCDF dimension dimension names to domain dimension names.
     # 
     # For example:
@@ -641,7 +643,8 @@ cell_methods)
                     # complaint? Don't worry about it - it'll get
                     # turned into a 1-d, size 1 auxiliary coordinate
                     # construct, anyway
-                    dim = f.domain.new_axis_identifier()
+                    dim = f.insert_axis(1)
+#                    dim = f.domain.new_axis_identifier()
                     dimensions = [dim]
                 else:  
                     # Numeric valued scalar coordinate
