@@ -26,10 +26,10 @@ and auxiliary coordinate roles for different data variables.
 
 :Parameters:
 
-    fields : (arbitrarily nested sequence of) cf.Field or cf.FieldList
+    fields: (arbitrarily nested sequence of) `cf.Field` or `cf.FieldList`
         The field or fields to write to the file.
 
-    filename : str
+    filename: `str`
         The output netCDF file. Various type of expansion are applied
         to the file names:
         
@@ -53,7 +53,7 @@ and auxiliary coordinate roles for different data variables.
           to the "david", then ``'~$MYSELF/out.nc'`` is equivalent to
           ``'~david/out.nc'``.
   
-    fmt : str, optional
+    fmt: `str`, optional
         The format of the output file. One of:
 
            =====================  ================================================
@@ -70,15 +70,15 @@ and auxiliary coordinate roles for different data variables.
         By default the *fmt* is ``'NETCDF3_CLASSIC'``. Note that the
         netCDF3 formats may be slower than any of the other options.
 
-    overwrite: bool, optional
+    overwrite: `bool`, optional
         If False then raise an exception if the output file
         pre-exists. By default a pre-existing output file is over
         written.
 
-    verbose : bool, optional
+    verbose: `bool`, optional
         If True then print one-line summaries of each field written.
 
-    cfa_options : dict, optional
+    cfa_options: `dict`, optional
         A dictionary giving parameters for configuring the output
         CFA-netCDF file:
 
@@ -102,7 +102,7 @@ and auxiliary coordinate roles for different data variables.
 
         By default no parameters are specified.
     
-    mode : str, optional
+    mode: `str`, optional
         Specify the mode of write access for the output file. One of:
 
            =======  =====================================================
@@ -115,12 +115,12 @@ and auxiliary coordinate roles for different data variables.
        
         By default the file is opened with write access mode ``'w'``.
 
-    endian : str, optional
+    endian: `str`, optional
         The endian-ness of the output file. Valid values are
         ``'little'``, ``'big'`` or ``'native'``. By default the output
         is native endian.
 
-    compress : int, optional
+    compress: `int`, optional
         Regulate the speed and efficiency of compression. Must be an
         integer between ``0`` and ``9``. ``0`` means no compression;
         ``1`` is the fastest, but has the lowest compression ratio;
@@ -128,7 +128,7 @@ and auxiliary coordinate roles for different data variables.
         value is ``0``. An exception is raised if compression is
         requested for a netCDF3 output file format.
     
-    least_significant_digit : int, optional
+    least_significant_digit: `int`, optional
         Truncate the input field data arrays. For a positive integer,
         N the precision that is retained in the compressed data is '10
         to the power -N'. For example, a value of ``2`` will retain a
@@ -136,12 +136,12 @@ and auxiliary coordinate roles for different data variables.
         parameter this produces 'lossy', but significantly more
         efficient compression.
 
-    fletcher32 : bool, optional
+    fletcher32: `bool`, optional
         If True then the Fletcher-32 HDF5 checksum algorithm is
         activated to detect compression errors. Ignored if *compress*
         is ``0``.
 
-    no_shuffle : bool, optional
+    no_shuffle: `bool`, optional
         If True then the HDF5 shuffle filter (which de-interlaces a
         block of data before compression by reordering the bytes by
         storing the first byte of all of a variable's values in the
@@ -151,7 +151,7 @@ and auxiliary coordinate roles for different data variables.
         filter can make the data more easily compressible.  Ignored if
         *compress* is ``0``.
 
-    datatype : dict, optional
+    datatype: `dict`, optional
         Specify data type conversions to be applied prior to writing
         data to disk. Arrays with data types which are not specified
         remain unchanged. By default, input data types are
@@ -165,21 +165,21 @@ and auxiliary coordinate roles for different data variables.
             numpy.dtype('float32'), numpy.dtype('int64'):
             numpy.dtype('int32')}``.
        
-    single : bool, optional
+    single: `bool`, optional
         Write 64-bit floats as 32-bit floats and 64-bit integers as
         32-bit integers. By default, input data types are
         preserved. Note that ``single=True`` is exactly equivalent to
         ``datatype={numpy.dtype('float64'): numpy.dtype('float32'),
         numpy.dtype('int64'): numpy.dtype('int32')}``.
        
-    double : bool, optional
+    double: `bool`, optional
         Write 32-bit floats as 64-bit floats and 32-bit integers as
         64-bit integers. By default, input data types are
         preserved. Note that ``double=True`` is exactly equivalent to
         ``datatype={numpy.dtype('float32'): numpy.dtype('float64'),
         numpy.dtype('int32'): numpy.dtype('int64')}``.
  
-    HDF_chunksizes : dict, optional
+    HDF_chunksizes: `dict`, optional
         Manually specify HDF5 chunks for the field data arrays.
 
         Chunking refers to a storage layout where a data array is
